@@ -6,7 +6,7 @@ if (getRversion() >= "2.15.1") {
       "a_est", "a_lci", "a_uci", "circ_dist", "d_est", "d_lci", "d_uci", "e_est",
       "e_lci", "e_uci", "est", "f_lci", "f_uci", "fit", "key", "label", "lci",
       "octants", "quartile", "uci", "value", "x_est", "x_lci", "x_uci", "y_est",
-      "y_lci", "y_uci", "Scale", "Score", "Parameter", "lnty"
+      "y_lci", "y_uci", "Scale", "Score", "Parameter", "lnty", ".im", "Sample"
     )
   )
 }
